@@ -1,19 +1,23 @@
-# Copyright (c) 2012, 2014 Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 import os
 import sys
@@ -76,9 +80,6 @@ class MigrationTarget(object):
         self.state.targetVersion.releaseNumber = self.state.targetDBVersion.releaseNumber
 
     def connect(self):
-        if self.connection.driver.name == 'MysqlNativeSSH':
-            raise NotSupportedError('MySQL connections through SSH are not supported in this version '
-                                    'of the MySQL Workbench Migration Wizard.')
         return grt.modules.DbMySQLFE.connect(self.connection, self.password or "")
 
     def disconnect(self):
@@ -195,13 +196,7 @@ class MigrationSource(object):
     ignoreList = property(_get_ignore_list, _set_ignore_list)
 
     def connect(self):
-        if self.connection.driver.owner.name == 'Mysql' and self.connection.driver.name == 'MysqlNativeSSH':
-            raise NotSupportedError('MySQL connections through SSH are not supported in this version '
-                                    'of the MySQL Workbench Migration Wizard.')
         self._rev_eng_module.connect(self.connection, self.password or "")
-        #if str(self.getDriverDBMSName()).upper() == 'ACCESS':
-        #    raise NotSupportedError('Microsoft Access is not supported in this version of the MySQL Workbench '
-        #                            'Migration Wizard.')
         return True
 
     def disconnect(self):
@@ -390,7 +385,6 @@ class MigrationSource(object):
 class MigrationPlan(object):
 
     def __init__(self):
-        grt.modules.Workbench.initializeOtherRDBMS()
         self.state = grt.root.wb.migration
         if not self.state:
             self.state = grt.classes.db_migration_Migration()
@@ -439,6 +433,9 @@ class MigrationPlan(object):
     def close(self):
         if self.migrationSource:
             self.migrationSource.cleanup()
+            self.migrationSource.disconnect()
+        if self.migrationTarget:
+            self.migrationTarget.disconnect()
         self.state.owner = None
         grt.root.wb.migration = None
         self.state = None
