@@ -1,19 +1,23 @@
-# Copyright (c) 2007, 2014, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 import StringIO
 import socket
@@ -21,7 +25,7 @@ import threading
 import time
 
 from mforms import App
-from wb_server_management import wbaOS
+from wb_server_management import wbaOS, handle_ssh_command_output
 from wb_common import Users
 
 from workbench.log import log_info, log_error, log_debug, log_debug2, log_debug3
@@ -148,6 +152,7 @@ class ShellDataSource(DataSource):
 
     def poll(self):
         output = StringIO.StringIO()
+        
         if self.ctrl_be.server_helper.execute_command("/usr/bin/uptime", output_handler=output.write) == 0:
             data = output.getvalue().strip(" \r\t\n,:.").split("\n")[-1]
             self._cpu_stat_return = None
@@ -159,7 +164,7 @@ class ShellDataSource(DataSource):
             except (ValueError, TypeError):
                 log_error("Shell source %s returned wrong value. Expected int or float but got '%s'\n" % (self.name, load_value))
                 result = 0
-
+    
             if self.widget is not None:
                 self.widget.set_value(self.calc_cb(result) if self.calc_cb else result)
                 if self.label_cb is not None:
@@ -192,13 +197,21 @@ class WinRemoteStats(object):
         # where mysql.ini is.
         self.script = None
 
-        self.ssh   = ctrl_be.open_ssh_session_for_monitoring()
+        if self.ctrl_be.server_profile.uses_ssh:
+            if self.ctrl_be.editor.sshConnection.isConnected() == 0:
+                if self.ctrl_be.editor.sshConnection.connect() != 0:
+                    raise OperationCancelledError("Could not connect to SSH server")
+                self.ssh = sshConnection
+                
+        
+        if self.ssh is not None:
+            # %APPDATA% is n/a for LocalService
+            # which is a user sshd can be run
+            dirpath = handle_ssh_command_output(self.ssh.executeCommand("cmd /C echo %USERPROFILE%"))
 
-        (dirpath, code) = self.ssh.exec_cmd("cmd /C echo %USERPROFILE%") # %APPDATA% is n/a for LocalService
-                                                                         # which is a user sshd can be run
         dirpath = dirpath.strip(" \r\t\n")
 
-        if code == 0 and dirpath is not None and dirpath != "%USERPROFILE%":
+        if dirpath is not None and dirpath != "%USERPROFILE%":
             script_path = App.get().get_resource_path("mysql_system_status_rmt.vbs")
             filename = "\"" + dirpath + "\\mysql_system_status_rmt.vbs\""
             log_debug('Script local path is "%s". Will be uploaded to "%s"\n' % (script_path, filename) )
@@ -206,7 +219,7 @@ class WinRemoteStats(object):
                 #print "Uploading file to ", filename
                 try:
                     f = open(script_path)
-                    self.ssh.exec_cmd("cmd /C echo. > " + filename)
+                    handle_ssh_command_output(self.ssh.executeCommand("cmd /C echo. > " + filename))
                     maxsize = 1800
                     cmd = ""
                     for line in f:
@@ -215,15 +228,15 @@ class WinRemoteStats(object):
                         if len(tline) > 0:
                             if tline[0] != "'":
                                 if len(cmd) > maxsize:
-                                    self.ssh.exec_cmd("cmd /C " + cmd.strip(" &"))
-                                    self.ssh.exec_cmd("cmd /C echo " + line + " >> " + filename)
+                                    handle_ssh_command_output(self.ssh.executeCommand("cmd /C " + cmd.strip(" &")))
+                                    handle_ssh_command_output(self.ssh.executeCommand("cmd /C echo " + line + " >> " + filename))
                                     cmd = ""
                                 else:
                                     cmd += "echo " + line + " >> " + filename
                                     cmd += " && "
 
                     if len(cmd) > 0:
-                        self.ssh.exec_cmd("cmd /C " + cmd.strip(" &"))
+                        handle_ssh_command_output(self.ssh.executeCommand("cmd /C " + cmd.strip(" &")))
                         cmd = ""
 
                     self.script = "cscript //NoLogo " + filename + " /DoStdIn"
@@ -234,11 +247,11 @@ class WinRemoteStats(object):
                     self.chan = None
                     self.out = ""
 
-                    self.read_thread = threading.Thread(target=self.ssh.exec_cmd, args=(self.script, Users.CURRENT, None, self.reader, 1, self.save_channel))
+                    self.read_thread = threading.Thread(target=self.ssh.executeCommand, args=(self.script, Users.CURRENT, None, self.reader, 1, self.save_channel))
                     self.read_thread.setDaemon(True)
                     self.read_thread.start()
                 except IOError, e:
-                    self.ssh.close()
+                    self.ssh.disconnect()
                     self.ssh = None
                     raise e
         else:
@@ -254,7 +267,7 @@ class WinRemoteStats(object):
                     self.read_thread.join()
             except:
                 pass
-            self.ssh.close()
+            self.ssh.disconnect()
             self.ssh = None
 
     #-----------------------------------------------------------------------------
